#
# spec file for package cobbler
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib: %define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?pyver: %define pyver %(%{__python} -c "import sys ; print sys.version[:3]" || echo 0)}

%if 0%{?suse_version}
%define www_path /srv/
%define apache_user wwwrun
%define apache_group www
%define apachedir apache2
%else
%define www_path %{_var}
%define apache_user apache
%define apache_group apache
%define apachedir httpd
%endif

%define _binaries_in_noarch_packages_terminate_build 0
%global debug_package %{nil}
Summary:        Boot server configurator
License:        GPL-2.0+
Group:          Applications/System
Name:           cobbler
AutoReq:        no
Version:        2.6.6
Release:        8.2
Source0:        cobbler-%{version}.tar.gz
Source1:        vendor-files.tar.bz2
Source2:        fence_ipmitool.sh
Source3:        logrotate_cobbler
Patch2:         cobbler_web_config.diff
Patch5:         koan_old_cobbler_compat.diff
Patch6:         looking_for_cobbler_order_changed.diff
Patch7:         catch_cheetah_exception.patch
Patch9:         fix-restart-paravirt-xen.dif
Patch10:        disable_not_relevant_checks_bnc_828453.patch
Patch11:        fix-powermanagement-status.dif
Patch13:        fix_sle_detection.patch
Patch14:        use_grub2_on_suse.diff
Patch16:        fix-koan-port-guessing.dif
# PATCH-FIX-SLE name-of-file.patch bnc#883487 dmacvicar@suse.de
Patch18:        cobbler-2.4.2-reprovision-rhel-on-suse-bnc883487.patch
Patch19:        fix-broken-tests.diff
Patch20:        fix_test_create_systems.diff
Patch21:        remove_ks_directory_check.diff
Patch22:        add_generic_sles_signatures.diff
Patch23:        koan-virt-setup-suse.dif
Patch24:        koan-no-xend.dif
Patch25:        koan-detect-os_version.dif
Patch26:        koan-use-kvm-acceleration-if-available.dif
Patch27:        0001-1398-koan-incompatible-with-F21-virt-install.patch
Patch28:        virt-install-without-generic26.patch
Patch29:        koan-improve-virt-install-error-reports.patch
# PATCH-FIX-cobbler20
Patch30:        cobbler-modprobe-d.patch
Patch31:        fix-cobbler-yaboot-handling.patch
Patch32:        fix-error-message-in-cobblerd-status.dif
Patch33:        0001-cobbler-add-little-endian-powerpc-support.patch
Patch34:        fix-cobbler-buildiso.dif
Patch35:        cobbler-check-and-get-loaders-fix.patch
Patch36:        fix-textmode-for-SUSE.dif
Patch37:        adding-grub2-support-for-ppc.patch
Patch38:        localboot-fix-using-chain-c32.patch
Patch39:        support-grub2efi.patch
Patch40:        fix-script-endpoint-security-bug-1030582.patch
Patch41:        fix-koan-missing-args-and-location.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Url:            http://www.cobblerd.org/

BuildRequires:  git
BuildRequires:  python-cheetah
%if 0%{?suse_version}
BuildRequires:  apache2
BuildRequires:  atftp
BuildRequires:  distribution-release
BuildRequires:  fdupes
Requires:       apache2-mod_wsgi
Requires:       ipmitool
Requires:       python-PyYAML
%else
BuildRequires:  redhat-rpm-config
Requires:       PyYAML
Requires:       httpd
Requires:       mod_wsgi
%endif

Requires:       createrepo
Requires:       logrotate
Requires:       python >= 2.3
Requires:       python-cheetah
Requires:       python-netaddr
Requires:       python-simplejson
Requires:       python-urlgrabber
Requires:       rsync
%ifarch %ix86 x86_64
Requires:       syslinux
%endif
%ifarch s390x
Requires:       syslinux-x86_64
%endif
Requires:       tftp(server)

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6 || 0%{?suse_version}
Requires:       genisoimage
%else
Requires:       mkisofs
%endif

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6
Requires:       python(abi) >= %{pyver}
%endif

%if 0%{?fedora} >= 8
BuildRequires:  python-setuptools-devel
%else
BuildRequires:  python-setuptools
%endif

%if 0%{?fedora} >= 6 || 0%{?rhel} >= 5 || 0%{?suse_version}
Requires:       yum-utils
%endif

%if 0%{?fedora} >= 16
BuildRequires:  systemd-units
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
%if 0%{?suse_version}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else
Requires(post):  /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service
%endif
%endif

%description

Cobbler is a network install server.  Cobbler supports PXE,
virtualized installs, and re-installing existing Linux machines.  The
last two modes use a helper tool, 'koan', that integrates with
cobbler.  There is also a web interface 'cobbler-web'.  Cobbler's
advanced features include importing distributions from DVDs and rsync
mirrors, kickstart templating, integrated yum mirroring, and built-in
DHCP/DNS Management.  Cobbler has a XMLRPC API for integration with
other applications.

%prep
%setup -q
%setup -a1
%if 0%{?suse_version}
%patch2
%endif
%patch5
%patch6
%patch7 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch13 -p1
%if 0%{?suse_version}
%patch14 -p1
%endif
%patch16 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p0
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1

mv vendor-files/cobbler.1.gz docs

%build
%{__python} setup.py build

%install
test "x$RPM_BUILD_ROOT" != "x" && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/%{apachedir}/conf.d
%{__python} setup.py install --optimize=1 --skip-build --root=$RPM_BUILD_ROOT $PREFIX

mkdir -p $RPM_BUILD_ROOT/var/spool/koan

%if 0%{?fedora} >= 9 || 0%{?rhel} > 5
mkdir -p $RPM_BUILD_ROOT/var/lib/tftpboot/images
%else
%if 0%{?suse_version}
mkdir -p $RPM_BUILD_ROOT/srv/tftpboot/images
%else
mkdir -p $RPM_BUILD_ROOT/tftpboot/images
%endif
%endif

rm -f $RPM_BUILD_ROOT/etc/cobbler/cobblerd

%if 0%{?suse_version}
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/SuSEfirewall2.d
mv vendor-files/cobbler_firewall_settings $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/cobbler
install -m 755 %{S:2} $RPM_BUILD_ROOT/usr/sbin/fence_ipmitool

ln -sf service $RPM_BUILD_ROOT/usr/sbin/rccobblerd
cp -r tests/ $RPM_BUILD_ROOT/usr/share/cobbler/
%endif

# create logrote config
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
install -m 644 %{S:3} $RPM_BUILD_ROOT/etc/logrotate.d/cobbler

%if 0%{?fedora} >= 16 || 0%{?suse_version}
rm -rf $RPM_BUILD_ROOT/etc/init.d
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
mv $RPM_BUILD_ROOT%{_sysconfdir}/cobbler/cobblerd.service $RPM_BUILD_ROOT%{_unitdir}
%endif

%if 0%{?suse_version}
%fdupes %{buildroot}/usr
%endif

%if 0%{?suse_version}
%pre
%service_add_pre cobblerd.service

%post
if [ $1 -eq 1 ] ; then
    # Initial installation
    sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES proxy
    sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES proxy_http
    sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES proxy_connect
    sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES wsgi
elif [ "$1" -ge "2" ]; then
    # backup config
    if [ -e /var/lib/cobbler/distros ]; then
        cp /var/lib/cobbler/distros*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/profiles* /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/systems*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/repos*    /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/networks* /var/lib/cobbler/backup 2>/dev/null
    fi
    if [ -e /var/lib/cobbler/config ]; then
        cp -a /var/lib/cobbler/config    /var/lib/cobbler/backup 2>/dev/null
    fi
    # upgrade older installs
    # move power and pxe-templates from /etc/cobbler, backup new templates to *.rpmnew
    for n in power pxe; do
      rm -f /etc/cobbler/$n*.rpmnew
      find /etc/cobbler -maxdepth 1 -name "$n*" -type f | while read f; do
        newf=/etc/cobbler/$n/`basename $f`
        [ -e $newf ] &&  mv $newf $newf.rpmnew
        mv $f $newf
      done
    done
    # upgrade older installs
    # copy kickstarts from /etc/cobbler to /var/lib/cobbler/kickstarts
    rm -f /etc/cobbler/*.ks.rpmnew
    find /etc/cobbler -maxdepth 1 -name "*.ks" -type f | while read f; do
      newf=/var/lib/cobbler/kickstarts/`basename $f`
      [ -e $newf ] &&  mv $newf $newf.rpmnew
      cp $f $newf
    done
    # remove mod_python from apache
    sysconf_addword -r /etc/sysconfig/apache2 APACHE_MODULES python >/dev/null 2>&1
fi
%service_add_post cobblerd.service

%preun
%service_del_preun cobblerd.service

%postun
%service_del_postun cobblerd.service

%else
# not SUSE starts here
%post
if [ "$1" = "1" ];
then
    # This happens upon initial install. Upgrades will follow the next else
    /sbin/chkconfig --add cobblerd
elif [ "$1" -ge "2" ];
then
    # backup config
    if [ -e /var/lib/cobbler/distros ]; then
        cp /var/lib/cobbler/distros*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/profiles* /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/systems*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/repos*    /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/networks* /var/lib/cobbler/backup 2>/dev/null
    fi
    if [ -e /var/lib/cobbler/config ]; then
        cp -a /var/lib/cobbler/config    /var/lib/cobbler/backup 2>/dev/null
    fi
    # upgrade older installs
    # move power and pxe-templates from /etc/cobbler, backup new templates to *.rpmnew
    for n in power pxe; do
      rm -f /etc/cobbler/$n*.rpmnew
      find /etc/cobbler -maxdepth 1 -name "$n*" -type f | while read f; do
        newf=/etc/cobbler/$n/`basename $f`
        [ -e $newf ] &&  mv $newf $newf.rpmnew
        mv $f $newf
      done
    done
    # upgrade older installs
    # copy kickstarts from /etc/cobbler to /var/lib/cobbler/kickstarts
    rm -f /etc/cobbler/*.ks.rpmnew
    find /etc/cobbler -maxdepth 1 -name "*.ks" -type f | while read f; do
      newf=/var/lib/cobbler/kickstarts/`basename $f`
      [ -e $newf ] &&  mv $newf $newf.rpmnew
      cp $f $newf
    done
    # reserialize and restart
    # FIXIT: ?????
    #/usr/bin/cobbler reserialize
    /sbin/service cobblerd condrestart
fi

%preun
if [ $1 = 0 ]; then
    /sbin/service cobblerd stop >/dev/null 2>&1 || :
    chkconfig --del cobblerd || :
fi

%postun
if [ "$1" -ge "1" ]; then
    /sbin/service cobblerd condrestart >/dev/null 2>&1 || :
    /sbin/service httpd condrestart >/dev/null 2>&1 || :
fi

%endif

%clean
test "x$RPM_BUILD_ROOT" != "x" && rm -rf $RPM_BUILD_ROOT

%files

%defattr(-,root,root,-)

%{_bindir}/cobbler
%{_bindir}/cobbler-ext-nodes
%{_bindir}/cobblerd
%{_sbindir}/tftpd.py*

%config(noreplace) /etc/logrotate.d/cobbler
%config(noreplace) %{_sysconfdir}/cobbler
%if 0%{?fedora} >= 16 || 0%{?suse_version}
%{_unitdir}/cobblerd.service
%else
/etc/init.d/cobblerd
%endif

%{python_sitelib}/cobbler

%config(noreplace) /var/lib/cobbler
%exclude /var/lib/cobbler/webui_sessions

/var/log/cobbler
/%{www_path}/www/cobbler

%{_mandir}/man1/cobbler.1.gz

%config(noreplace) /etc/%{apachedir}/conf.d/cobbler.conf

%if 0%{?fedora} >= 9 || 0%{?rhel} >= 5 || 0%{?suse_version}
%exclude %{python_sitelib}/cobbler/sub_process.py*
%endif
%if 0%{?fedora} >= 9 || 0%{?rhel} > 5 || 0%{?suse_version}
%{python_sitelib}/cobbler*.egg-info
%if 0%{?suse_version}
/srv/tftpboot/images
%else
/var/lib/tftpboot/images
%endif
%else
/tftpboot/images
%endif

%doc AUTHORS README COPYING
%if 0%{?suse_version}
%config /etc/sysconfig/SuSEfirewall2.d/cobbler
/usr/sbin/fence_ipmitool
/usr/sbin/rccobblerd
%endif

%package -n koan

Summary:        Helper tool that performs cobbler orders on remote machines
Group:          Applications/System
Requires:       python >= 2.0
Requires:       python-simplejson
Requires:       virt-install
%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6
Requires:       python(abi) >= %{pyver}
%endif

%description -n koan

Koan stands for kickstart-over-a-network and allows for both
network installation of new virtualized guests and reinstallation
of an existing system.  For use with a boot-server configured with Cobbler

%files -n koan
%defattr(-,root,root,-)
%dir /var/spool/koan
%dir /var/lib/koan
%dir /var/lib/koan/config
%{_bindir}/koan
%{_bindir}/ovz-install
%{_bindir}/cobbler-register
%{python_sitelib}/koan

%if 0%{?fedora} >= 9 || 0%{?rhel} >= 5 || 0%{?suse_version}
%exclude %{python_sitelib}/koan/sub_process.py*
%exclude %{python_sitelib}/koan/opt_parse.py*
%exclude %{python_sitelib}/koan/text_wrap.py*
%endif

%{_mandir}/man1/koan.1.gz
%{_mandir}/man1/cobbler-register.1.gz
%dir /var/log/koan
%doc AUTHORS COPYING README

%package -n cobbler-web

Summary:        Web interface for Cobbler
Group:          Applications/System
Requires:       cobbler
%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6
Requires:       Django >= 1.1.2
Requires:       mod_ssl
Requires:       mod_wsgi
Requires:       python(abi) >= %{pyver}
%endif
%if 0%{?suse_version}
Requires:       apache2-mod_wsgi
Requires:       python-django
%endif

%description -n cobbler-web

Web interface for Cobbler that allows visiting
http://server/cobbler_web to configure the install server.

%post -n cobbler-web
# Change the SECRET_KEY option in the Django settings.py file
# required for security reasons, should be unique on all systems
RAND_SECRET=$(openssl rand -base64 40 | sed 's/\//\\\//g')
sed -i -e "s/SECRET_KEY = ''/SECRET_KEY = \'$RAND_SECRET\'/" /usr/share/cobbler/web/settings.py

%files -n cobbler-web
%defattr(-,root,root,-)
%doc AUTHORS COPYING README
%config(noreplace) /etc/%{apachedir}/conf.d/cobbler_web.conf
%defattr(-,%{apache_user},%{apache_group},-)
/usr/share/cobbler/web
%dir %attr(700,%{apache_user},root) /var/lib/cobbler/webui_sessions
/%{www_path}/www/cobbler_webui_content/
%if 0%{?suse_version}
%dir /usr/share/cobbler
%endif

%if 0%{?suse_version}
%package -n cobbler-tests

Summary:        Unit tests for Cobbler
Group:          Applications/System
Requires:       cobbler

%description -n cobbler-tests

Unit test files from the Cobbler project

%files -n cobbler-tests
%defattr(-,root,root,-)
/usr/share/cobbler/tests
%endif #suse_version

%changelog
* Wed Aug  9 2017 mseidl@suse.de
- missed applying last patch in spec file
* Wed Aug  9 2017 mseidl@suse.de
- (bsc#1048183) fix missing args and location for xen
* Wed Jun  7 2017 mihai.dinca@suse.com
- fix script endpoint security bug CVE-2016-9605 (bsc#1030582)
  Add:
  * fix-script-endpoint-security-bug-1030582.patch
* Tue Apr  4 2017 mc@suse.de
- support UEFI boot with cobbler generated tftp tree (bsc#1020376)
* Tue Mar 21 2017 mantel@suse.de
- remove fix-nameserver-search.fix; bug is invalid (bsc#1029276)
* Wed Mar 15 2017 mantel@suse.de
- refresh patch for fuzzless appliance
* Wed Mar 15 2017 mantel@suse.de
- some more occurrences of same problem fixed (bsc#1029276)
* Tue Mar 14 2017 mantel@suse.de
- name_servers needs the same fix (bsc#1029276)
* Tue Mar 14 2017 mantel@suse.de
- fix handling of name_servers_search in networking.xml bsc#1029276
* Thu Nov 24 2016 pablo.suarezhernandez@suse.com
- Using "chain.c32" instead of "LOCALBOOT -1" for the local boot
  entry in pxe menu (bsc#988889)
  Add:
  * localboot-fix-using-chain-c32.patch
* Thu Sep  1 2016 pablo.suarezhernandez@suse.com
- Enabling PXE grub2 support for PowerPC (bsc#986978)
  Add:
  * adding-grub2-support-for-ppc.patch
* Fri Jun 17 2016 mc@suse.de
- convert bootoption "text" into "textmode=1" for SUSE systems
  (bsc#984998)
  Add:
  * fix-textmode-for-SUSE.dif
* Tue May 17 2016 mc@suse.de
- remove grubby-compat because perl-Bootloader gets dropped
  Remove:
  * grubby-compat.diff
  * do_not_use_grubby_compat_when_grub2_is_in_use.diff
  Add:
  * use_grub2_on_suse.diff
* Fri May 13 2016 pablo.suarezhernandez@suse.com
- Disabling 'get-loaders' command and 'check' fixed. bsc#973418
  Added:
  * cobbler-check-and-get-loaders-fix.patch
* Fri Apr 22 2016 mc@suse.de
- add logrotate file for cobbler (bsc#976826)
* Thu Mar 31 2016 mc@suse.de
- handle list value for kernel options correctly (bsc#973413)
* Wed Mar 16 2016 mc@suse.de
- add ppc64le to archs
  * 0001-cobbler-add-little-endian-powerpc-support.patch
* Mon Mar  7 2016 mc@suse.de
- fix error message in cobblerd status when cobbler-web is
  not installed (bsc#966841)
* Fri Mar  4 2016 mc@suse.de
- fix format error while provisioning of a virtual machine
  (bsc#969541)
  Update: koan-improve-virt-install-error-reports.patch
* Wed Mar  2 2016 mc@suse.de
- support modprobe.d on RHEL6
  * cobbler-modprobe-d.patch
- fix cobbler yaboot handling (bsc#968406, bsc#966622)
  * fix-cobbler-yaboot-handling.patch
* Wed Feb 24 2016 mc@suse.de
- improve error reporting of failed virt-install commands
  Add: koan-improve-virt-install-error-reports.patch
* Tue Feb 23 2016 mc@suse.de
- fallback to osinfo-query for new virt-install (bsc#967523)
  * 0001-1398-koan-incompatible-with-F21-virt-install.patch
- fix for virt-install without os version generic26 (bsc#967523)
  * virt-install-without-generic26.patch
* Mon Nov  9 2015 mc@suse.de
- cleanup spec file. The cobbler main package should see a
  SUSE system as systemd only (bsc#952844)
* Thu Mar 26 2015 mc@suse.de
- koan: fix virt-install version detection (bsc#924118)
- koan: fix parsing install_tree for SUSE (bsc#924118)
- koan: do not require obsoleted xend (bsc#924118)
- koan: fix boot configuration for XEN directly after VM creation.
    This prevent endless installation loop (bsc#924118)
- koan: improve os-variant detection for SLES
- koan: use KVM acceleration if available
* Mon Feb 16 2015 mseidl@suse.de
- Renamed generic suse breed "suse"
* Mon Feb 16 2015 mseidl@suse.de
- Added generic os under breed suse
* Fri Feb 13 2015 mseidl@suse.de
- fixed supported arches
- added generic sles11, sles10 and sles12 signatures
* Wed Feb 11 2015 mseidl@suse.de
- Removed directory check for kickstart files
* Wed Feb 11 2015 dmacvicar@suse.de
- Do not manually install cobbler.conf
  setup.py does it and replaces variables in the process
* Thu Jan 15 2015 fcastelli@suse.com
- Added 'fix_test_create_systems.diff': fixes the "create_systens" unit test
* Tue Jan 13 2015 fcastelli@suse.com
- Fix runtime dependency: ensure the yaml module is available.
* Tue Jan 13 2015 fcastelli@suse.com
- Install the right cobblerd.service file
* Mon Jan 12 2015 fcastelli@suse.com
- Do not ship cobbler_web.conf inside of the cobbler package, get rid
  of part of our patches to setup.py,
* Fri Dec 19 2014 fcastelli@suse.com
- Added new patch required to fix the broken unit tests:
  * fix-broken-tests.diff
* Thu Dec 18 2014 fcastelli@suse.com
- Removed another no longer needed patch:
  * fix-textmode-for-SUSE.dif
* Thu Dec 18 2014 fcastelli@suse.com
- Update to latest stable version of cobbler (2.6.6)
- Removed no longer needed patches
  * bnc_877009.patch
  * cobbler-2.4.2-Fix-koan-s-get_insert_script.patch
  * fix-broken-tests.diff
  * suse_config.diff
- Fixed old patches to apply against the new code:
  * catch_cheetah_exception.patch
  * grubby-compat.diff
  * setup_py.diff
* Mon Dec 15 2014 fcastelli@suse.com
- Fix the broken unit tests
* Thu Dec 11 2014 mseidl@suse.de
- Created sub package for unit tests
* Tue Dec  9 2014 mc@suse.de
- use fdupes only on SUSE
* Mon Dec  8 2014 dmacvicar@suse.de
- Fix for re-installation of machines on SLE with static
  network configuration (bnc#883487)
- Added patches:
  * cobbler-2.4.2-Fix-koan-s-get_insert_script.patch
  * cobbler-2.4.2-reprovision-rhel-on-suse-bnc883487.patch
* Thu Nov 27 2014 mc@suse.de
- fix port guessing in koan (bsc#855389)
  * fix-koan-port-guessing.dif
- add "copy-default" option to grubby-compat (bsc#855389)
- handle elilo in SUSE (bsc#855389)
* Wed Nov 26 2014 mc@suse.de
- fix wrong option "text" in SUSE environment (bsc#901058)
  * fix-textmode-for-SUSE.dif
* Thu Sep  4 2014 fcastelli@suse.com
- Added do_not_use_grubby_compat_when_grub2_is_in_use.diff: prevents
  usage of grubby-compat when grub2 is active. Use grub2 features
  do modify the boot loader.
* Tue Sep  2 2014 fcastelli@suse.com
- Moved grubby-compat inside of the koan sub-package. The scrit was accidentally
  moved into the cobbler package.
* Fri Jul 25 2014 fcastelli@suse.com
- Added fix_sle_detection.patch: ensures SLE12 is properly detected.
* Fri Jul 25 2014 fcastelli@suse.com
- Fixed and error 'grubby-compat.diff' patch which broke koan tool
- Added bnc_877009.patch, fixes CVE-2014-3225: cobbler: Local files
  inclusion (bnc#877009)
* Fri Jul 11 2014 mc@suse.de
- Remove patch which automatically escapes cobbler templates.
  (bnc#869371)
- require syslinux-x86_64 on s390x (bnc#884051)
* Wed Jul  9 2014 mc@suse.de
- mod_python is not needed anymore for cobbler
  remove module from apache configuration
* Thu Jul  3 2014 mseidl@suse.de
- modified to work with aftpd
* Fri Feb 14 2014 mc@suse.de
- update to version 2.4.2
  + Adding support for gPXE
  + Adding support for ESXi5
  + fix install=... kernel parameter when importing a SUSE distro
  + koan: Port xen creation to virt-install
  + koan: Port qcreate to virt-install
  + Port koan from virtinst to virt-install command (v2)
  + add qcow2 driver type
  + Adding ability to use https for API calls (cobbler CLI)
  + Use ip instead of ifconfig for network snippets
  + minor modifications to templar to show template rendering errors
  + bugfixes and refactoring
  obsolete patches (available upstream):
  * cobbler-man-fix.dif
  * fix-initscript.dif
  * fix-setting-system-to-image.dif
  * fix-snippet.dif
  * fix_suse_import.diff
  * fix_version_format.diff
  * fix-xen-fullvirt-install.dif
  * koan_distro_files_fix.diff
  * security_fix_xmlrpc_command_injection.diff
  * fix-http-check-on-SUSE-platform.patch
  * users_patch.diff
* Wed Dec 11 2013 cdenicolo@suse.com
- license update: GPL-2.0+
  SPDX name
* Wed Nov 13 2013 fcastelli@suse.com
- Fix man page inconsistencies.
* Fri Nov  8 2013 mc@suse.de
- fix evaluation of power status calls
* Mon Nov  4 2013 mc@suse.de
- fix wrong options in the man page (bnc#846580)
* Thu Oct 31 2013 mc@suse.com
- fix adding image to system
* Wed Oct 30 2013 mc@suse.de
- add fence_ipmitool script for power management
- require ipmitool
* Thu Oct 17 2013 mc@suse.de
- fix networking.xml snippet and use the correct key for getting
  the netmask (bnc#842699)
* Wed Jul 10 2013 fcastelli@suse.com
- Fix cobbler checks on SUSE (bnc#828453)
* Wed Apr  3 2013 mc@suse.de
- koan requires python-urlgrabber (bnc#812948)
* Wed Mar 27 2013 mc@suse.de
- fix XEN fullvirt installation
* Tue Mar 26 2013 mc@suse.de
- fix restart of new created paravirt XEN systems (bnc#811025)
* Fri Jan  4 2013 mc@suse.de
- fix autoescaping to not strip empty lines. This keep GPG keys
  in a kickstart profile working (bnc#796773)
* Wed Nov 21 2012 mc@suse.de
- do not auto escape snippets (bnc#790545)
* Fri Nov 16 2012 bo@suse.de
- Templates don't need to be dollar sign escaped any longer.
  (bnc#790545)
* Mon Nov 12 2012 mc@suse.de
- forward cheetah exception as 500 SERVER ERROR (bnc#787879)
* Thu Aug 23 2012 mc@suse.de
- install grubby-compat to /sbin (bnc#783671)
* Thu May 24 2012 ug@suse.de
- VUL-0: cobbler: remote code execution flaw
  bnc#763610
* Tue May 22 2012 ug@suse.de
- changed the order to look for cobbler. Try https first
  to avoid exception
* Tue May 22 2012 ug@suse.de
- requires fixed in spec file
* Wed May 16 2012 ug@suse.de
- added compatibility code for koan 2.2.2 to cobbler 2.0.10
* Tue May 15 2012 ug@suse.de
- added grubby-compat patch again
- some spec file fixes
* Wed May  9 2012 ug@suse.de
- build on RHEL6 fixed
* Wed May  9 2012 ug@suse.de
- build on RHEL fixed
* Wed May  9 2012 ug@suse.de
- build on SLES10 fixed
* Thu May  3 2012 ug@suse.de
- requires syslinux only on x86 architecture
* Fri Apr 20 2012 ug@suse.de
- changed the XMLRPC API call version() to return a float
  instead of a string
* Wed Apr 18 2012 ug@suse.de
- don't overwrite existing kernel/initrd when reinstalling
  a machine (bnc#722443)
* Mon Apr 16 2012 ug@suse.de
- VUL-0: CVE-2011-4953
  cobbler: privilege escalation flaw / local root
    (bnc#757062)
* Tue Mar 27 2012 chris@computersalat.de
- update to 2.2.2
  * please see CHANGELOG for more info
- remove obsolete virt-auto-boot patch
- rebase patches
* Mon Feb 13 2012 ug@suse.de
- fixed return value of rccobblerd status
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec 22 2011 ug@suse.de
- fix install=... kernel option when you import a SUSE distro
* Wed Oct 26 2011 ug@suse.de
- virtual machines autostart on boot fixed
* Wed Oct 19 2011 ug@suse.de
- quotes fixed for the kernel parameters in menu.lst (bnc#722445)
- Virtual systems don't get restarted on restart of host
  (bnc#695955)
- allowed length of the kernel options line changed
  from 256 to 2048 characters
* Tue Sep 27 2011 ug@suse.de
- koan requires python-urlgrabber
* Fri Sep 23 2011 ug@suse.de
- build on RES fixed
* Thu Sep 22 2011 ug@suse.de
- Require in spec-file fixed
* Fri Sep 16 2011 ug@suse.de
- added grubby-compat patch (bnc#672471)
* Mon Sep 12 2011 mc@suse.de
- no python-virtinst on Code10
* Wed Jun  8 2011 ug@suse.de
- koan reads the architecture for virtual machines from cobbler
  (fate#312397 and bnc#682665)
- ISO build parameters for a SUSE system fixed
- cheetah rendering before XML parsing now, to avoid problems
  with the XML parser and cheetah instructions
- Add possibility to interrupt zPXE and to enter CMS
- changed defaults for s390 to be more SUSE like (bnc#687891)
* Wed Apr 27 2011 ug@suse.de
- fixed a broken timezone setting in cobbler-web
* Wed Apr 27 2011 ug@suse.de
- building for SLE10 fixed
* Wed Mar 23 2011 ug@suse.de
- VUL-0: cobbler: logrotate:
  issues with service owned directories
  bnc#678433
* Fri Feb 18 2011 ug@suse.de
- removed python-devel in requirement
* Thu Feb 17 2011 kkaempf@novell.com
- Fix build on RHEL
* Thu Feb 17 2011 ug@suse.de
- added missing rc-script link (bnc#671212)
* Wed Feb 16 2011 ug@suse.de
- cheetah_class_fix.diff added to fix a cheetah version check
* Fri Feb 11 2011 mc@suse.de
- cobbler_wsgi.conf will not be packaged
* Wed Feb  9 2011 ro@suse.de
- require syslinux only on x86 and x86_64
* Wed Feb  9 2011 ro@suse.de
- fix config file location on RH
* Tue Feb  8 2011 ma@novell.com
- fix specfile
* Tue Feb  8 2011 mc@suse.de
- require python-virtinst in SUSE
* Thu Feb  3 2011 ug@suse.de
- packaged the cobbler.conf file instead of the cobbler_wsgi.conf
  file again (bnc#668968)
* Wed Feb  2 2011 mc@suse.de
- require python-virtinst only for RHEL >= 5
* Wed Feb  2 2011 mc@suse.de
- require grubby only on SUSE
* Wed Feb  2 2011 mc@suse.de
- fix suse_version check in spec file
- fix build on RH
* Fri Jan 28 2011 ug@suse.de
- fixed the apache config
* Wed Jan 19 2011 ug@suse.de
- firewall settings added
* Fri Jan 14 2011 ug@suse.de
- debug switch in specfile removed to make it build again
* Thu Jan 13 2011 ug@suse.de
- version update to 2.0.10 because of many bugs ins 2.0.8
* Wed Jan 12 2011 ug@suse.de
- some template files were not packed since 2.0.8
* Tue Jan 11 2011 ug@suse.de
- version update to 2.0.8 (bnc#660126)
* Tue Dec 21 2010 ug@suse.de
- fixed spec file
* Thu Sep  9 2010 kkaempf@novell.com
- remove 'xinetd' from Required-Start
